"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/minio.ts
var minio_exports = {};
__export(minio_exports, {
  DEFAULT_BUCKET: () => DEFAULT_BUCKET,
  createPresignedUploadUrl: () => createPresignedUploadUrl,
  createServerMinioClient: () => createServerMinioClient,
  deleteFile: () => deleteFile,
  getFileById: () => getFileById,
  getFilesList: () => getFilesList,
  uploadFile: () => uploadFile
});
module.exports = __toCommonJS(minio_exports);
var import_runtime3 = require("@settlemint/sdk-utils/runtime");
var import_validation3 = require("@settlemint/sdk-utils/validation");
var import_minio = require("minio");

// src/helpers/client-options.schema.ts
var import_validation = require("@settlemint/sdk-utils/validation");
var import_zod = require("zod");
var ServerClientOptionsSchema = import_zod.z.object({
  /** The URL of the MinIO instance to connect to */
  instance: import_validation.UrlSchema,
  /** The MinIO access key used to authenticate with the MinIO server */
  accessKey: import_zod.z.string(),
  /** The MinIO secret key used to authenticate with the MinIO server */
  secretKey: import_zod.z.string()
});

// src/helpers/functions.ts
var import_runtime2 = require("@settlemint/sdk-utils/runtime");
var import_validation2 = require("@settlemint/sdk-utils/validation");

// src/helpers/executor.ts
var import_runtime = require("@settlemint/sdk-utils/runtime");
async function executeMinioOperation(client, operation) {
  (0, import_runtime.ensureServer)();
  return operation.execute(client);
}

// src/helpers/operations.ts
function createListObjectsOperation(bucket, prefix = "") {
  return {
    execute: async (client) => {
      const objectsStream = client.listObjects(bucket, prefix, true);
      const objects = [];
      return new Promise((resolve, reject) => {
        objectsStream.on("data", (obj) => {
          if (obj.name && typeof obj.size === "number" && obj.etag && obj.lastModified) {
            objects.push({
              name: obj.name,
              prefix: obj.prefix,
              size: obj.size,
              etag: obj.etag,
              lastModified: obj.lastModified
            });
          }
        });
        objectsStream.on("error", (err) => {
          reject(err);
        });
        objectsStream.on("end", () => {
          resolve(objects);
        });
      });
    }
  };
}
function createStatObjectOperation(bucket, objectName) {
  return {
    execute: async (client) => {
      return client.statObject(bucket, objectName);
    }
  };
}
function createDeleteOperation(bucket, objectName) {
  return {
    execute: async (client) => {
      return client.removeObject(bucket, objectName);
    }
  };
}
function createPresignedUrlOperation(bucket, objectName, expirySeconds) {
  return {
    execute: async (client) => {
      return client.presignedGetObject(bucket, objectName, expirySeconds);
    }
  };
}
function createPresignedPutOperation(bucket, objectName, expirySeconds) {
  return {
    execute: async (client) => {
      return client.presignedPutObject(bucket, objectName, expirySeconds);
    }
  };
}
function createSimpleUploadOperation(client) {
  return async (buffer, bucket, objectName, metadata) => {
    return client.putObject(bucket, objectName, buffer, void 0, metadata);
  };
}

// src/helpers/schema.ts
var import_zod2 = require("zod");
var FileMetadataSchema = import_zod2.z.object({
  id: import_zod2.z.string(),
  name: import_zod2.z.string(),
  contentType: import_zod2.z.string(),
  size: import_zod2.z.number(),
  uploadedAt: import_zod2.z.string().datetime(),
  etag: import_zod2.z.string(),
  url: import_zod2.z.string().url().optional()
});
var DEFAULT_BUCKET = "uploads";

// src/helpers/functions.ts
function normalizePath(path, fileName) {
  if (path.length > 1e3) {
    throw new Error("Path is too long");
  }
  const cleanPath = path.replace(/\/+$/, "");
  if (!cleanPath) {
    return fileName;
  }
  return `${cleanPath}/${fileName}`;
}
async function getFilesList(client, prefix = "", bucket = DEFAULT_BUCKET) {
  (0, import_runtime2.ensureServer)();
  console.log(`Listing files with prefix: "${prefix}" in bucket: "${bucket}"`);
  try {
    const listOperation = createListObjectsOperation(bucket, prefix);
    const objects = await executeMinioOperation(client, listOperation);
    console.log(`Found ${objects.length} files in MinIO`);
    const fileObjects = await Promise.all(
      objects.map(async (obj) => {
        const presignedUrlOperation = createPresignedUrlOperation(
          bucket,
          obj.name,
          3600
          // 1 hour expiry
        );
        const url = await executeMinioOperation(client, presignedUrlOperation);
        return {
          id: obj.name,
          name: obj.name.split("/").pop() || obj.name,
          contentType: "application/octet-stream",
          // Default type
          size: obj.size,
          uploadedAt: obj.lastModified.toISOString(),
          etag: obj.etag,
          url
        };
      })
    );
    return (0, import_validation2.validate)(FileMetadataSchema.array(), fileObjects);
  } catch (error) {
    console.error("Failed to list files:", error);
    throw new Error(`Failed to list files: ${error instanceof Error ? error.message : String(error)}`);
  }
}
async function getFileById(client, fileId, bucket = DEFAULT_BUCKET) {
  (0, import_runtime2.ensureServer)();
  console.log(`Getting file details for: ${fileId} in bucket: ${bucket}`);
  try {
    const statOperation = createStatObjectOperation(bucket, fileId);
    const statResult = await executeMinioOperation(client, statOperation);
    const presignedUrlOperation = createPresignedUrlOperation(
      bucket,
      fileId,
      3600
      // 1 hour expiry
    );
    const url = await executeMinioOperation(client, presignedUrlOperation);
    let size = 0;
    if (statResult.metaData["content-length"]) {
      const parsedSize = Number.parseInt(statResult.metaData["content-length"], 10);
      if (!Number.isNaN(parsedSize)) {
        size = parsedSize;
      }
    } else if (typeof statResult.size === "number" && !Number.isNaN(statResult.size)) {
      size = statResult.size;
    }
    const fileMetadata = {
      id: fileId,
      name: fileId.split("/").pop() || fileId,
      contentType: statResult.metaData["content-type"] || "application/octet-stream",
      size,
      uploadedAt: statResult.lastModified.toISOString(),
      etag: statResult.etag,
      url
    };
    return (0, import_validation2.validate)(FileMetadataSchema, fileMetadata);
  } catch (error) {
    console.error(`Failed to get file ${fileId}:`, error);
    throw new Error(`Failed to get file ${fileId}: ${error instanceof Error ? error.message : String(error)}`);
  }
}
async function deleteFile(client, fileId, bucket = DEFAULT_BUCKET) {
  (0, import_runtime2.ensureServer)();
  try {
    const deleteOperation = createDeleteOperation(bucket, fileId);
    await executeMinioOperation(client, deleteOperation);
    return true;
  } catch (error) {
    console.error(`Failed to delete file ${fileId}:`, error);
    throw new Error(`Failed to delete file ${fileId}: ${error instanceof Error ? error.message : String(error)}`);
  }
}
async function createPresignedUploadUrl(client, fileName, path = "", bucket = DEFAULT_BUCKET, expirySeconds = 3600) {
  (0, import_runtime2.ensureServer)();
  try {
    const safeFileName = fileName.replace(/[^a-zA-Z0-9._-]/g, "_");
    const objectName = normalizePath(path, safeFileName);
    const presignedPutOperation = createPresignedPutOperation(bucket, objectName, expirySeconds);
    const url = await executeMinioOperation(client, presignedPutOperation);
    if (!url) {
      throw new Error("Failed to generate presigned upload URL");
    }
    return url;
  } catch (error) {
    console.error("Failed to create presigned upload URL:", error);
    throw new Error(`Failed to create presigned upload URL: ${error instanceof Error ? error.message : String(error)}`);
  }
}
async function uploadFile(client, buffer, objectName, contentType, bucket = DEFAULT_BUCKET) {
  (0, import_runtime2.ensureServer)();
  try {
    const metadata = {
      "content-type": contentType,
      "upload-time": (/* @__PURE__ */ new Date()).toISOString()
    };
    const simpleUploadFn = createSimpleUploadOperation(client);
    const result = await simpleUploadFn(buffer, bucket, objectName, metadata);
    const presignedUrlOperation = createPresignedUrlOperation(
      bucket,
      objectName,
      3600
      // 1 hour expiry
    );
    const url = await executeMinioOperation(client, presignedUrlOperation);
    const fileName = objectName.split("/").pop() || objectName;
    const fileMetadata = {
      id: objectName,
      name: fileName,
      contentType,
      size: buffer.length,
      uploadedAt: (/* @__PURE__ */ new Date()).toISOString(),
      etag: result.etag,
      url
    };
    return (0, import_validation2.validate)(FileMetadataSchema, fileMetadata);
  } catch (error) {
    console.error("Failed to upload file:", error);
    throw new Error(`Failed to upload file: ${error instanceof Error ? error.message : String(error)}`);
  }
}

// src/minio.ts
function createServerMinioClient(options) {
  (0, import_runtime3.ensureServer)();
  const validatedOptions = (0, import_validation3.validate)(ServerClientOptionsSchema, options);
  const url = new URL(validatedOptions.instance);
  return {
    client: new import_minio.Client({
      endPoint: url.hostname,
      accessKey: validatedOptions.accessKey,
      secretKey: validatedOptions.secretKey,
      useSSL: url.protocol !== "http:",
      port: url.port ? Number(url.port) : void 0,
      region: "eu-central-1"
    })
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DEFAULT_BUCKET,
  createPresignedUploadUrl,
  createServerMinioClient,
  deleteFile,
  getFileById,
  getFilesList,
  uploadFile
});
//# sourceMappingURL=minio.cjs.map